==> atlas-authorization-2.2.0-sources.jar: org/apache/atlas/authorize/AtlasAuthorizationException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.authorize;

public class AtlasAuthorizationException extends Exception {
    private static final long serialVersionUID = 1L;

    public AtlasAuthorizationException(String message) {
        super(message);
    }

    public AtlasAuthorizationException(String message, Throwable exception) {
        super(message, exception);
    }

    public AtlasAuthorizationException(String message, Throwable exception, boolean enableSuppression,
        boolean writableStackTrace) {
        super(message, exception, enableSuppression, writableStackTrace);
    }

    public AtlasAuthorizationException(AtlasAccessRequest request) {
        super("Unauthorized Request : " + request);
    }
}

==> atlas-authorization-3.0.0-20250914.001612-16380-sources.jar: org/apache/atlas/authorize/AtlasAuthorizationException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.atlas.authorize;

public class AtlasAuthorizationException extends Exception {
    private static final long serialVersionUID = 1L;

    public AtlasAuthorizationException(String message) {
        super(message);
    }

    public AtlasAuthorizationException(String message, Throwable exception) {
        super(message, exception);
    }

    public AtlasAuthorizationException(String message, Throwable exception, boolean enableSuppression, boolean writableStackTrace) {
        super(message, exception, enableSuppression, writableStackTrace);
    }

    public AtlasAuthorizationException(AtlasAccessRequest request) {
        super("Unauthorized Request : " + request);
    }
}
